@@ -1,16 +1,16 @@
 #!/bin/sh
 
 # defaults
-DRIVERPATH="/opt/lib/modules/$1/" 
+DRIVERPATH="/opt/packet-injection-modules/$1/" 
 FILEPATH="/home/user/.cleven"
 
 # Check if needed files exist
-if [ -f $DRIVERPATH/updates/compat/compat.ko ] &&
-   [ -f $DRIVERPATH/updates/net/rfkill/rfkill_backport.ko ] &&
-   [ -f $DRIVERPATH/updates/net/wireless/cfg80211.ko ] &&
-   [ -f $DRIVERPATH/updates/net/mac80211/mac80211.ko ] &&
-   [ -f $DRIVERPATH/updates/drivers/net/wireless/wl1251/wl1251.ko ] &&
-   [ -f $DRIVERPATH/updates/drivers/net/wireless/wl1251/wl1251_spi.ko ]; then 
+if [ -f $DRIVERPATH/compat.ko ] &&
+   [ -f $DRIVERPATH/rfkill_backport.ko ] &&
+   [ -f $DRIVERPATH/cfg80211.ko ] &&
+   [ -f $DRIVERPATH/mac80211.ko ] &&
+   [ -f $DRIVERPATH/wl1251.ko ] &&
+   [ -f $DRIVERPATH/wl1251_spi.ko ]; then 
     echo "INFO: Driver files found.."
 else 
     echo "ERROR: Some or all driver files are missing. Interrupting this action."
@@ -35,12 +35,12 @@ rmmod compat_firmware_class 2>/dev/null
 rmmod compat 2>/dev/null
 
 # Load bleeding-edge wl1251
-insmod $DRIVERPATH/updates/compat/compat.ko
-insmod $DRIVERPATH/updates/net/rfkill/rfkill_backport.ko
-insmod $DRIVERPATH/updates/net/wireless/cfg80211.ko
-insmod $DRIVERPATH/updates/net/mac80211/mac80211.ko
-insmod $DRIVERPATH/updates/drivers/net/wireless/wl1251/wl1251.ko
-insmod $DRIVERPATH/updates/drivers/net/wireless/wl1251/wl1251_spi.ko
+insmod $DRIVERPATH/compat.ko
+insmod $DRIVERPATH/rfkill_backport.ko
+insmod $DRIVERPATH/cfg80211.ko
+insmod $DRIVERPATH/mac80211.ko
+insmod $DRIVERPATH/wl1251.ko
+insmod $DRIVERPATH/wl1251_spi.ko
    
 # Restore mac address
 ifconfig wlan0 down hw ether "$MACADDR"
